@@ -13,6 +13,8 @@
 #include "core/InfomapCore.h"
 #include "io/Config.h"
 #include <string>
+#include <utility>
+#include <map>
 
 namespace infomap {
 
@@ -47,6 +49,8 @@ public:
 
   void setBipartiteStartId(unsigned int startId) { m_network.setBipartiteStartId(startId); }
 
+  std::map<std::pair<unsigned int, unsigned int>, double> getLinks(bool flow);
+
   std::map<unsigned int, unsigned int> getModules(int level = 1, bool states = false);
   std::map<unsigned int, std::vector<unsigned int>> getMultilevelModules(bool states = false);
   using InfomapCore::codelength;
